@@ -35,7 +35,17 @@ class TestCreditCardMetaBuilder(TestCase):
     def setUp(self):
         self.cardBuilder = CreditCardMetaBuilder()
 
-    def testBuild(self):
-        self.cardBuilder.ccnumber = "4304222233334444"
-        self.cardBuilder.ccName = "John Doe"
+    def CCBuild(self):
+        creditcard = self.cardBuilder.build()
+
+    def test_normal_build(self):
+        self.cardBuilder.ccnumber = "5430422223333444"
+        self.cardBuilder.ccName = 'John Doe'
         self.cardBuilder.build()
+
+    def test_attr_error_build(self):
+        self.cardBuilder.ccnumber = "5430422223333444"
+        self.assertRaises(AttributeError,self.cardBuilder.build)
+
+    def test_invalid_length_build(self):
+        self.assertRaises(MetaBuilder.ValidatorError,self.cardBuilder.ccnumber,"543042222333444")
\ No newline at end of file
